.. _cookbook:

The Cookbook
============

yt provides a great deal of functionality to the user, but sometimes it can
be a bit complex.  This section of the documentation lays out examples recipes
for how to do a variety of tasks.  Most of the early, simple code
demonstrations are small scripts which you can easily copy and paste into
your own code; however, as we move to more complex tasks, the recipes move to
iPython notebooks to display intermediate steps.  All of these recipes are
available for download in a link next to the recipe.

Getting the Sample Data
-----------------------

All of the data used in the cookbook is freely available
`here <https://yt-project.org/data/>`_, where you will find links to download
individual datasets.

.. note:: To contribute your own recipes, please follow the instructions
    on how to contribute documentation code: :ref:`writing_documentation`.

Example Scripts
---------------
.. toctree::
   :maxdepth: 2

   simple_plots
   calculating_information
   complex_plots
   constructing_data_objects

.. _example-notebooks:

Example Notebooks
-----------------
.. toctree::
   :maxdepth: 1

   notebook_tutorial
   custom_colorbar_tickmarks
   gadget_notebook
   owls_notebook
   ../visualizing/transfer_function_helper
   fits_radio_cubes
   fits_xray_images
   geographic_projections
   tipsy_notebook
   ../visualizing/volume_rendering_tutorial
